emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] 07/09: Rename ggtags-with-process-environment


From: Leo Liu
Subject: [elpa] 07/09: Rename ggtags-with-process-environment
Date: Tue, 18 Feb 2014 02:56:17 +0000

leoliu pushed a commit to branch master
in repository elpa.

commit ef1794153540f46d2d7e294932547c6eeff3b5a4
Author: Leo Liu <address@hidden>
Date:   Mon Feb 17 11:00:22 2014 +0800

    Rename ggtags-with-process-environment
    
    to ggtags-with-current-project.
---
 ggtags.el |   19 ++++++++++---------
 1 files changed, 10 insertions(+), 9 deletions(-)

diff --git a/ggtags.el b/ggtags.el
index 87d7127..c381c3c 100644
--- a/ggtags.el
+++ b/ggtags.el
@@ -355,7 +355,7 @@ properly update `ggtags-mode-map'."
   (ggtags-check-project)
   (let* ((inhibit-read-only t)          ; for `add-dir-local-variable'
          (default-directory (ggtags-current-project-root))
          ;; Not using `ggtags-with-process-environment' to preserve
          ;; environment variables that may be present in
          ;; `ggtags-process-environment'.
          (process-environment
@@ -402,7 +402,8 @@ properly update `ggtags-mode-map'."
       (message "Project read-only-mode is %s" (if val "on" "off")))
     val))
 
-(defmacro ggtags-with-process-environment (&rest body)
+(defmacro ggtags-with-current-project (&rest body)
+  "Eval BODY in current project's `process-environment'."
   (declare (debug t))
   (let ((gtagsroot (make-symbol "-gtagsroot-"))
         (ggproj (make-symbol "-ggtags-project-")))
@@ -432,7 +433,7 @@ properly update `ggtags-mode-map'."
     (when (zerop (length root)) (error "No root directory provided"))
     (setenv "GTAGSROOT"
             (directory-file-name (file-name-as-directory root)))
-    (ggtags-with-process-environment
+    (ggtags-with-current-project
      (and (not (getenv "GTAGSLABEL"))
           (yes-or-no-p "Use `ctags' backend? ")
           (setenv "GTAGSLABEL" "ctags"))
@@ -455,7 +456,7 @@ non-nil."
   (when (or force (and (ggtags-find-project)
                        (not (ggtags-project-oversize-p))
                        (ggtags-project-dirty-p (ggtags-find-project))))
-    (ggtags-with-process-environment
+    (ggtags-with-current-project
      (with-temp-message "`global -u' in progress..."
        (ggtags-process-string "global" "-u")
        (setf (ggtags-project-dirty-p (ggtags-find-project)) nil)))))
@@ -468,7 +469,7 @@ non-nil."
      (unless (equal prefix (car ggtags-completion-cache))
        (setq ggtags-completion-cache
              (cons prefix
-                   (ggtags-with-process-environment
+                   (ggtags-with-current-project
                     (split-string
                      (apply #'ggtags-process-string
                             "global"
@@ -548,7 +549,7 @@ non-nil."
     (setq ggtags-global-exit-status 0
           ggtags-global-match-count 0)
     (ggtags-update-tags)
-    (ggtags-with-process-environment
+    (ggtags-with-current-project
      (setq ggtags-global-last-buffer
            (compilation-start command 'ggtags-global-mode)))))
 
@@ -716,7 +717,7 @@ Global and Emacs."
   (or (file-exists-p (expand-file-name "HTML" (ggtags-current-project-root)))
       (if (yes-or-no-p "No hypertext form exists; run htags? ")
           (let ((default-directory (ggtags-current-project-root)))
-            (ggtags-with-process-environment (ggtags-process-string "htags")))
+            (ggtags-with-current-project (ggtags-process-string "htags")))
         (user-error "Aborted")))
   (let ((url (ggtags-process-string "gozilla" "-p" (format "+%d" line)
                                     (file-relative-name file))))
@@ -1192,7 +1193,7 @@ Global and Emacs."
     (setf (ggtags-project-dirty-p (ggtags-find-project)) t)
     ;; When oversize update on a per-save basis.
     (when (and buffer-file-name (ggtags-project-oversize-p))
-      (ggtags-with-process-environment
+      (ggtags-with-current-project
        (process-file "global" nil 0 nil "--single-update"
                      (file-relative-name buffer-file-name))))))
 
@@ -1366,7 +1367,7 @@ Global and Emacs."
   (when-let (file (and buffer-file-name (file-relative-name buffer-file-name)))
     (with-temp-buffer
       (when (with-demoted-errors
-              (zerop (ggtags-with-process-environment
+              (zerop (ggtags-with-current-project
                       (process-file "global" nil t nil "-x" "-f" file))))
         (goto-char (point-min))
         (loop while (re-search-forward
@@ -355,7 +355,7 @@ properly update `ggtags-mode-map'."
   (let* ((inhibit-read-only t)          ; for `add-dir-local-variable'
          (default-directory (ggtags-current-project-root))
-         ;; Not using `ggtags-with-process-environment' to preserve
+         ;; Not using `ggtags-with-current-project' to preserve
          ;; environment variables that may be present in
          ;; `ggtags-process-environment'.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]